@@ -181,7 +181,7 @@ cm_csrgen_o_main(int fd, struct cm_store_ca *ca, struct cm_store_entry *entry,
 	BIGNUM *serialbn;
 	char buf[LINE_MAX], *s, *nickname, *pin, *password, *filename;
 	unsigned char *extensions, *upassword, *bmp, *name, *up, *uq, md[CM_DIGEST_MAX];
-	char *spkidec, *mcb64, *nows;
+	char *spkidec = NULL, *mcb64, *nows;
 	const char *default_cn = CM_DEFAULT_CERT_SUBJECT_CN, *spkihex = NULL;
 	const unsigned char *nametmp;
 	struct tm *now;
@@ -200,9 +200,8 @@ cm_csrgen_o_main(int fd, struct cm_store_ca *ca, struct cm_store_entry *entry,
 	    (strlen(entry->cm_key_next_marker) > 0)) {
 		filename = util_build_next_filename(entry->cm_key_storage_location, entry->cm_key_next_marker);
 		if (filename == NULL) {
-			cm_log(1, "Error opening key file \"%s\" "
-			       "for reading: %s.\n",
-			       filename, strerror(errno));
+			cm_log(1, "Error opening key file for reading: %s.\n",
+			       strerror(errno));
 			_exit(CM_SUB_STATUS_INTERNAL_ERROR);
 		}
 	} else {
@@ -346,7 +345,7 @@ cm_csrgen_o_main(int fd, struct cm_store_ca *ca, struct cm_store_entry *entry,
 							  strlen(password));
 			}
 			X509_REQ_sign(req, pkey, cm_prefs_ossl_hash());
-			PEM_write_X509_REQ_NEW(status, req);
+			PEM_write_X509_REQ(status, req);
 			/* Generate the SPKAC. */
 			memset(&spkac, 0, sizeof(spkac));
 			spkac.challenge = util_ASN1_IA5STRING_new();
