@@ -124,7 +124,7 @@ cm_keyiread_n_get_keys(struct cm_store_entry *entry, int readwrite)
 			      (readwrite ? 0 : NSS_INIT_READONLY) |
 			      NSS_INIT_NOROOTINIT);
 	if (ctx == NULL) {
-		cm_log(0, "Unable to initialize NSS.\n");
+		cm_log(0, "Unable to initialize NSS %s.\n", entry->cm_key_storage_location);
 		_exit(1);
 	}
 	reason = util_n_fips_hook();
