@@ -194,7 +194,7 @@ cm_scepgen_n_main(int fd, struct cm_store_ca *ca, struct cm_store_entry *entry,
 			      NSS_INIT_READONLY |
 			      NSS_INIT_NOROOTINIT);
 	if (ctx == NULL) {
-		cm_log(0, "Unable to initialize NSS.\n");
+		cm_log(0, "Unable to initialize NSS %s.\n", entry->cm_key_storage_location);
 		_exit(1);
 	}
 	reason = util_n_fips_hook();
