@@ -587,32 +587,34 @@ cm_submit_e_postprocess_main(int fd, struct cm_store_ca *ca,
 				   estate->msg_length, NULL);
 		msg = cm_json_new_object(estate);
 		chain = cm_json_new_array(msg);
-		if (leaf != NULL) {
-			cert = cm_json_new_string(msg, leaf, -1);
-			cm_json_set(msg, CM_SUBMIT_E_CERTIFICATE, cert);
-		}
-		for (i = 0;
-		     (others != NULL) && (others[i] != NULL);
-		     i++) {
-			cert = cm_json_new_object(chain);
-			val = cm_json_new_string(cert, others[i], -1);
-			cm_json_set(cert, CM_SUBMIT_E_CERTIFICATE, val);
-			nthnick = talloc_asprintf(cert, "chain #%d", i + 1);
-			nick = cm_json_new_string(cert, nthnick, -1);
-			cm_json_set(cert, CM_SUBMIT_E_NICKNAME, nick);
-			cm_json_append(chain, cert);
-		}
-		if (top!= NULL) {
-			cert = cm_json_new_object(chain);
-			val = cm_json_new_string(cert, top, -1);
-			cm_json_set(cert, CM_SUBMIT_E_CERTIFICATE, val);
-			nthnick = talloc_asprintf(cert, "chain #%d", i + 1);
-			nick = cm_json_new_string(cert, nthnick, -1);
-			cm_json_set(cert, CM_SUBMIT_E_NICKNAME, nick);
-			cm_json_append(chain, cert);
-		}
-		if (cm_json_array_size(chain) > 0) {
-			cm_json_set(msg, CM_SUBMIT_E_CHAIN, chain);
+		if (i == 0) {
+			if (leaf != NULL) {
+				cert = cm_json_new_string(msg, leaf, -1);
+				cm_json_set(msg, CM_SUBMIT_E_CERTIFICATE, cert);
+			}
+			for (i = 0;
+			     (others != NULL) && (others[i] != NULL);
+			     i++) {
+				cert = cm_json_new_object(chain);
+				val = cm_json_new_string(cert, others[i], -1);
+				cm_json_set(cert, CM_SUBMIT_E_CERTIFICATE, val);
+				nthnick = talloc_asprintf(cert, "chain #%d", i + 1);
+				nick = cm_json_new_string(cert, nthnick, -1);
+				cm_json_set(cert, CM_SUBMIT_E_NICKNAME, nick);
+				cm_json_append(chain, cert);
+			}
+			if (top!= NULL) {
+				cert = cm_json_new_object(chain);
+				val = cm_json_new_string(cert, top, -1);
+				cm_json_set(cert, CM_SUBMIT_E_CERTIFICATE, val);
+				nthnick = talloc_asprintf(cert, "chain #%d", i + 1);
+				nick = cm_json_new_string(cert, nthnick, -1);
+				cm_json_set(cert, CM_SUBMIT_E_NICKNAME, nick);
+				cm_json_append(chain, cert);
+			}
+			if (cm_json_array_size(chain) > 0) {
+				cm_json_set(msg, CM_SUBMIT_E_CHAIN, chain);
+			}
 		}
 	}
 	/* Get ready to build an output message. */
@@ -939,8 +941,8 @@ cm_submit_e_helper_main(int fd, struct cm_store_ca *ca,
 		}
 		return -1;
 	}
-	cm_log(2, "Redirecting stdin and stderr to /dev/null, leaving stdout open for child \"%s\".\n", argv[0]);
-	cm_subproc_mark_most_cloexec(STDOUT_FILENO, -1, -1);
+	cm_log(2, "Redirecting stdin to /dev/null, leaving stdout and stderr open for child \"%s\".\n", argv[0]);
+	cm_subproc_mark_most_cloexec(STDOUT_FILENO, STDERR_FILENO, -1);
 	cm_log(1, "Running enrollment helper \"%s\".\n", argv[0]);
 	execvp(argv[0], argv);
 	u = errno;
