@@ -914,9 +914,8 @@ main(int argc, const char **argv)
 
 	/* Maybe we need a ccache. */
 	if (k5 || (kpname != NULL) || (ktname != NULL)) {
-		if (!make_ccache ||
-		    (cm_submit_x_make_ccache(ktname, kpname, NULL) == 0)) {
-			k5 = TRUE;
+		if (!make_ccache) {
+		    cm_submit_x_make_ccache(ktname, kpname, NULL);
 		}
 	}
 
@@ -935,6 +934,7 @@ main(int argc, const char **argv)
 		} else {
 			cm_submit_x_add_named_arg_s(ctx, skey, sval);
 		}
+		free(skey);
 	}
 
 	/* Submit the request. */
