@@ -38,11 +38,15 @@ for state in \
 	CA_WORKING \
 	GENERATING_CSR \
 	GENERATING_KEY_PAIR \
+	GENERATING_SCEP_DATA \
 	HAVE_CSR \
 	HAVE_KEYINFO \
 	HAVE_KEY_PAIR \
+	HAVE_SCEP_DATA \
 	MONITORING \
 	NEED_CA \
+	NEED_CA_CERT_SAVE_PERMS \
+	NEED_CERTSAVE_PERMS \
 	NEED_CSR \
 	NEED_CSR_GEN_PIN \
 	NEED_CSR_GEN_TOKEN \
@@ -54,13 +58,22 @@ for state in \
 	NEED_KEYINFO_READ_PIN \
 	NEED_KEYINFO_READ_TOKEN \
 	NEED_KEY_PAIR \
-	NEED_TO_NOTIFY_ISSUED_FAILED \
+	NEED_ONLY_CA_CERT_SAVE_PERMS \
+	NEED_SCEP_DATA \
+	NEED_SCEP_ENCRYPTION_CERT \
+	NEED_SCEP_GEN_PIN \
+	NEED_SCEP_GEN_TOKEN \
+	NEED_SCEP_RSA_CLIENT_KEY \
+	NEED_TO_NOTIFY_ISSUED_CA_SAVE_FAILED \
 	NEED_TO_NOTIFY_ISSUED_SAVED \
+	NEED_TO_NOTIFY_ISSUED_SAVE_FAILED \
+	NEED_TO_NOTIFY_ONLY_CA_SAVE_FAILED \
 	NEED_TO_NOTIFY_REJECTION \
 	NEED_TO_NOTIFY_VALIDITY \
 	NEED_TO_READ_CERT \
 	NEED_TO_SAVE_CA_CERTS \
 	NEED_TO_SAVE_CERT \
+	NEED_TO_SAVE_ONLY_CA_CERTS \
 	NEED_TO_SUBMIT \
 	NEWLY_ADDED \
 	NEWLY_ADDED_DECIDING \
@@ -70,8 +83,10 @@ for state in \
 	NEWLY_ADDED_READING_KEYINFO \
 	NEWLY_ADDED_START_READING_CERT \
 	NEWLY_ADDED_START_READING_KEYINFO \
-	NOTIFYING_ISSUED_FAILED \
+	NOTIFYING_ISSUED_CA_SAVE_FAILED \
 	NOTIFYING_ISSUED_SAVED \
+	NOTIFYING_ISSUED_SAVE_FAILED \
+	NOTIFYING_ONLY_CA_SAVE_FAILED \
 	NOTIFYING_REJECTION \
 	NOTIFYING_VALIDITY \
 	POST_SAVED_CERT \
@@ -81,10 +96,10 @@ for state in \
 	SAVED_CERT \
 	SAVING_CA_CERTS \
 	SAVING_CERT \
-	NEED_CA_CERT_SAVE_PERMS \
-	NEED_CERTSAVE_PERMS \
+	SAVING_ONLY_CA_CERTS \
 	START_SAVING_CA_CERTS \
 	START_SAVING_CERT \
+	START_SAVING_ONLY_CA_CERTS \
 	SUBMITTING \
 	; do
 cat > entry << EOF
